import { currentPosition } from '../stores/chatRoom';

export function getCurrentPosition() {
	if (currentPosition.value) {
		return Promise.resolve(currentPosition.value);
	}
	const p = new Promise<{
		latitude: number;
		longitude: number;
	}>((resolve, reject) => {
		try {
			const geoLocation = window.plus ? plus.geolocation : navigator.geolocation;
			if (geoLocation) {
				geoLocation.getCurrentPosition(
					(position) => {
						const { latitude, longitude } = position.coords;
						currentPosition.value = {
							latitude,
							longitude,
						};
						resolve({
							latitude,
							longitude,
						});
					},

					(error) => {
						resolve(null);
					}
				);
			} else {
				console.log('Geolocation is not supported by this browser.');
				resolve(null);
			}
		} catch (error) {
			resolve(null);
		}
	});
	return p;
}
